# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='auth.service.proto',
  package='auth.api',
  syntax='proto3',
  serialized_pb=_b('\n\x12\x61uth.service.proto\x12\x08\x61uth.api\x1a\x1cgoogle/api/annotations.proto\"4\n\x0eVerifyTokenReq\x12\r\n\x05token\x18\x02 \x01(\t\x12\x13\n\x0b\x63lient_type\x18\x03 \x01(\t\"@\n\x0eVerifyTokenRsp\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\"\n\x07profile\x18\x02 \x01(\x0b\x32\x11.auth.api.Profile\"\x92\x01\n\x07Profile\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x35\n\nproperties\x18\x03 \x03(\x0b\x32!.auth.api.Profile.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32r\n\x0b\x41uthService\x12\x63\n\x0bVerifyToken\x12\x18.auth.api.VerifyTokenReq\x1a\x18.auth.api.VerifyTokenRsp\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/auth/token/verify:\x01*B/Z-nextfin.com/nfplatform/core/api/auth;auth_apib\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_VERIFYTOKENREQ = _descriptor.Descriptor(
  name='VerifyTokenReq',
  full_name='auth.api.VerifyTokenReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='auth.api.VerifyTokenReq.token', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_type', full_name='auth.api.VerifyTokenReq.client_type', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=114,
)


_VERIFYTOKENRSP = _descriptor.Descriptor(
  name='VerifyTokenRsp',
  full_name='auth.api.VerifyTokenRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='auth.api.VerifyTokenRsp.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='profile', full_name='auth.api.VerifyTokenRsp.profile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=180,
)


_PROFILE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='auth.api.Profile.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='auth.api.Profile.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='auth.api.Profile.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=329,
)

_PROFILE = _descriptor.Descriptor(
  name='Profile',
  full_name='auth.api.Profile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='auth.api.Profile.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='auth.api.Profile.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='auth.api.Profile.properties', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PROFILE_PROPERTIESENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=329,
)

_VERIFYTOKENRSP.fields_by_name['profile'].message_type = _PROFILE
_PROFILE_PROPERTIESENTRY.containing_type = _PROFILE
_PROFILE.fields_by_name['properties'].message_type = _PROFILE_PROPERTIESENTRY
DESCRIPTOR.message_types_by_name['VerifyTokenReq'] = _VERIFYTOKENREQ
DESCRIPTOR.message_types_by_name['VerifyTokenRsp'] = _VERIFYTOKENRSP
DESCRIPTOR.message_types_by_name['Profile'] = _PROFILE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VerifyTokenReq = _reflection.GeneratedProtocolMessageType('VerifyTokenReq', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYTOKENREQ,
  __module__ = 'auth.service_pb2'
  # @@protoc_insertion_point(class_scope:auth.api.VerifyTokenReq)
  ))
_sym_db.RegisterMessage(VerifyTokenReq)

VerifyTokenRsp = _reflection.GeneratedProtocolMessageType('VerifyTokenRsp', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYTOKENRSP,
  __module__ = 'auth.service_pb2'
  # @@protoc_insertion_point(class_scope:auth.api.VerifyTokenRsp)
  ))
_sym_db.RegisterMessage(VerifyTokenRsp)

Profile = _reflection.GeneratedProtocolMessageType('Profile', (_message.Message,), dict(

  PropertiesEntry = _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _PROFILE_PROPERTIESENTRY,
    __module__ = 'auth.service_pb2'
    # @@protoc_insertion_point(class_scope:auth.api.Profile.PropertiesEntry)
    ))
  ,
  DESCRIPTOR = _PROFILE,
  __module__ = 'auth.service_pb2'
  # @@protoc_insertion_point(class_scope:auth.api.Profile)
  ))
_sym_db.RegisterMessage(Profile)
_sym_db.RegisterMessage(Profile.PropertiesEntry)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z-nextfin.com/nfplatform/core/api/auth;auth_api'))
_PROFILE_PROPERTIESENTRY.has_options = True
_PROFILE_PROPERTIESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))

_AUTHSERVICE = _descriptor.ServiceDescriptor(
  name='AuthService',
  full_name='auth.api.AuthService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=331,
  serialized_end=445,
  methods=[
  _descriptor.MethodDescriptor(
    name='VerifyToken',
    full_name='auth.api.AuthService.VerifyToken',
    index=0,
    containing_service=None,
    input_type=_VERIFYTOKENREQ,
    output_type=_VERIFYTOKENRSP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\032\"\025/v1/auth/token/verify:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHSERVICE)

DESCRIPTOR.services_by_name['AuthService'] = _AUTHSERVICE

# @@protoc_insertion_point(module_scope)
