# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/api/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nf.pb.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core/api/common.proto',
  package='core.api',
  syntax='proto3',
  serialized_pb=_b('\n\x15\x63ore/api/common.proto\x12\x08\x63ore.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"2\n\x08Property\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0b\n\x03val\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x87\x01\n\x06\x46ilter\x12\x0e\n\x06\x66ields\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x0c\n\x04sort\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x05\x12\x10\n\x08pagesize\x18\x06 \x01(\x05\x12\x10\n\x08\x66romdate\x18\x07 \x01(\t\x12\x0e\n\x06todate\x18\x08 \x01(\t\"1\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04info\x18\x03 \x01(\t\"\x8d\x01\n\x11\x43onnectionAddress\x12\r\n\x05title\x18\x01 \x01(\t\x12\x39\n\x07\x61\x64\x64ress\x18\x02 \x03(\x0b\x32(.core.api.ConnectionAddress.AddressEntry\x1a.\n\x0c\x41\x64\x64ressEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf4\x01\n\x10\x43onnectionStatus\x12\r\n\x05state\x18\x01 \x01(\x05\x12\x1e\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0f.core.api.Error\"\xb0\x01\n\x05State\x12\x11\n\rState_UNKNOWN\x10\x00\x12\x14\n\x10State_CONNECTING\x10\x01\x12\x13\n\x0fState_CONNECTED\x10\x02\x12\x12\n\x0eState_LOGGEDIN\x10\x03\x12\x17\n\x13State_DISCONNECTING\x10\x04\x12\x16\n\x12State_DISCONNECTED\x10\x05\x12\x0f\n\x0bState_ERROR\x10\x06\x12\x13\n\x0fState_LOGGEDOUT\x10\x07\"\x8b\x01\n\x03Log\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\x10\n\x08owner_id\x18\x04 \x01(\t\x12\x46\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x16\x90\xdf\x1f\x01\xf2\xde\x1f\x0exorm:\"created\"\"#\n\x04Logs\x12\x1b\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\r.core.api.Log\"A\n\tHeartbeat\x12\x34\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\"\xa6\x03\n\nSymbolInfo\x12\x0f\n\x07symbole\x18\x01 \x01(\t\x12\x0f\n\x07marcket\x18\x02 \x01(\t\x12\r\n\x05\x66ront\x18\x03 \x01(\t\x12\x0c\n\x04rear\x18\x04 \x01(\t\x12\x17\n\x0fprice_precision\x18\x05 \x01(\x05\x12\x18\n\x10\x61mount_precision\x18\x06 \x01(\x05\x12\x17\n\x0f\x63ontract_period\x18\x07 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x08 \x01(\t\x12\r\n\x05quote\x18\t \x01(\t\x12\x36\n\x0clisting_date\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x35\n\x0bsettle_date\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x14\n\x0cmax_leverage\x18\x0c \x01(\x01\x12\x0f\n\x07min_pos\x18\r \x01(\x05\x12\x13\n\x0bquote_value\x18\x0e \x01(\x01\x12\x15\n\rsettlCurrency\x18\x0f \x01(\t\x12\x19\n\x11position_currency\x18\x10 \x01(\t\x12\x13\n\x0bmarket_name\x18\x11 \x01(\t\"4\n\x0e\x43ommSymbolInfo\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.core.api.SymbolInfo\"5\n\x0f\x43ommSymbolInfos\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.core.api.SymbolInfo\"\xa2\x01\n\x10StrategyTemplate\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x13\n\x0bsort_weight\x18\x05 \x01(\x05\x12\x12\n\nparam_info\x18\x06 \x01(\t\x12\x12\n\nparam_mode\x18\x07 \x01(\x05\x12\x10\n\x08stg_type\x18\x08 \x01(\x05\"@\n\x14StrategyTemplateItem\x12(\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1a.core.api.StrategyTemplate\"A\n\x15StrategyTemplateItems\x12(\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1a.core.api.StrategyTemplateB*Z(nextfin.com/nfplatform/core/api;core_apib\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])



_CONNECTIONSTATUS_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='core.api.ConnectionStatus.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='State_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_CONNECTING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_CONNECTED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_LOGGEDIN', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_DISCONNECTING', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_DISCONNECTED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_ERROR', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='State_LOGGEDOUT', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=544,
  serialized_end=720,
)
_sym_db.RegisterEnumDescriptor(_CONNECTIONSTATUS_STATE)


_PROPERTY = _descriptor.Descriptor(
  name='Property',
  full_name='core.api.Property',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='core.api.Property.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val', full_name='core.api.Property.val', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='core.api.Property.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=140,
)


_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='core.api.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='core.api.Filter.fields', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='core.api.Filter.filter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort', full_name='core.api.Filter.sort', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='limit', full_name='core.api.Filter.limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='page', full_name='core.api.Filter.page', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pagesize', full_name='core.api.Filter.pagesize', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fromdate', full_name='core.api.Filter.fromdate', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='todate', full_name='core.api.Filter.todate', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=278,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='core.api.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='core.api.Error.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='core.api.Error.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='info', full_name='core.api.Error.info', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=329,
)


_CONNECTIONADDRESS_ADDRESSENTRY = _descriptor.Descriptor(
  name='AddressEntry',
  full_name='core.api.ConnectionAddress.AddressEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='core.api.ConnectionAddress.AddressEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='core.api.ConnectionAddress.AddressEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=473,
)

_CONNECTIONADDRESS = _descriptor.Descriptor(
  name='ConnectionAddress',
  full_name='core.api.ConnectionAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='core.api.ConnectionAddress.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='address', full_name='core.api.ConnectionAddress.address', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CONNECTIONADDRESS_ADDRESSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=473,
)


_CONNECTIONSTATUS = _descriptor.Descriptor(
  name='ConnectionStatus',
  full_name='core.api.ConnectionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='core.api.ConnectionStatus.state', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='core.api.ConnectionStatus.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTIONSTATUS_STATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=476,
  serialized_end=720,
)


_LOG = _descriptor.Descriptor(
  name='Log',
  full_name='core.api.Log',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='core.api.Log.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='core.api.Log.level', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg', full_name='core.api.Log.msg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='core.api.Log.owner_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.Log.created_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=723,
  serialized_end=862,
)


_LOGS = _descriptor.Descriptor(
  name='Logs',
  full_name='core.api.Logs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.Logs.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=899,
)


_HEARTBEAT = _descriptor.Descriptor(
  name='Heartbeat',
  full_name='core.api.Heartbeat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='created_at', full_name='core.api.Heartbeat.created_at', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=901,
  serialized_end=966,
)


_SYMBOLINFO = _descriptor.Descriptor(
  name='SymbolInfo',
  full_name='core.api.SymbolInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbole', full_name='core.api.SymbolInfo.symbole', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='marcket', full_name='core.api.SymbolInfo.marcket', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='core.api.SymbolInfo.front', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='core.api.SymbolInfo.rear', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price_precision', full_name='core.api.SymbolInfo.price_precision', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount_precision', full_name='core.api.SymbolInfo.amount_precision', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contract_period', full_name='core.api.SymbolInfo.contract_period', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base', full_name='core.api.SymbolInfo.base', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quote', full_name='core.api.SymbolInfo.quote', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='listing_date', full_name='core.api.SymbolInfo.listing_date', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='settle_date', full_name='core.api.SymbolInfo.settle_date', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
    _descriptor.FieldDescriptor(
      name='max_leverage', full_name='core.api.SymbolInfo.max_leverage', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_pos', full_name='core.api.SymbolInfo.min_pos', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quote_value', full_name='core.api.SymbolInfo.quote_value', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='settlCurrency', full_name='core.api.SymbolInfo.settlCurrency', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position_currency', full_name='core.api.SymbolInfo.position_currency', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='market_name', full_name='core.api.SymbolInfo.market_name', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1391,
)


_COMMSYMBOLINFO = _descriptor.Descriptor(
  name='CommSymbolInfo',
  full_name='core.api.CommSymbolInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.CommSymbolInfo.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1445,
)


_COMMSYMBOLINFOS = _descriptor.Descriptor(
  name='CommSymbolInfos',
  full_name='core.api.CommSymbolInfos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.CommSymbolInfos.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=1500,
)


_STRATEGYTEMPLATE = _descriptor.Descriptor(
  name='StrategyTemplate',
  full_name='core.api.StrategyTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_id', full_name='core.api.StrategyTemplate.template_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='core.api.StrategyTemplate.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc', full_name='core.api.StrategyTemplate.desc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='core.api.StrategyTemplate.source', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort_weight', full_name='core.api.StrategyTemplate.sort_weight', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param_info', full_name='core.api.StrategyTemplate.param_info', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param_mode', full_name='core.api.StrategyTemplate.param_mode', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stg_type', full_name='core.api.StrategyTemplate.stg_type', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1503,
  serialized_end=1665,
)


_STRATEGYTEMPLATEITEM = _descriptor.Descriptor(
  name='StrategyTemplateItem',
  full_name='core.api.StrategyTemplateItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.StrategyTemplateItem.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=1731,
)


_STRATEGYTEMPLATEITEMS = _descriptor.Descriptor(
  name='StrategyTemplateItems',
  full_name='core.api.StrategyTemplateItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='core.api.StrategyTemplateItems.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1733,
  serialized_end=1798,
)

_CONNECTIONADDRESS_ADDRESSENTRY.containing_type = _CONNECTIONADDRESS
_CONNECTIONADDRESS.fields_by_name['address'].message_type = _CONNECTIONADDRESS_ADDRESSENTRY
_CONNECTIONSTATUS.fields_by_name['error'].message_type = _ERROR
_CONNECTIONSTATUS_STATE.containing_type = _CONNECTIONSTATUS
_LOG.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGS.fields_by_name['data'].message_type = _LOG
_HEARTBEAT.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SYMBOLINFO.fields_by_name['listing_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SYMBOLINFO.fields_by_name['settle_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMSYMBOLINFO.fields_by_name['data'].message_type = _SYMBOLINFO
_COMMSYMBOLINFOS.fields_by_name['data'].message_type = _SYMBOLINFO
_STRATEGYTEMPLATEITEM.fields_by_name['data'].message_type = _STRATEGYTEMPLATE
_STRATEGYTEMPLATEITEMS.fields_by_name['data'].message_type = _STRATEGYTEMPLATE
DESCRIPTOR.message_types_by_name['Property'] = _PROPERTY
DESCRIPTOR.message_types_by_name['Filter'] = _FILTER
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['ConnectionAddress'] = _CONNECTIONADDRESS
DESCRIPTOR.message_types_by_name['ConnectionStatus'] = _CONNECTIONSTATUS
DESCRIPTOR.message_types_by_name['Log'] = _LOG
DESCRIPTOR.message_types_by_name['Logs'] = _LOGS
DESCRIPTOR.message_types_by_name['Heartbeat'] = _HEARTBEAT
DESCRIPTOR.message_types_by_name['SymbolInfo'] = _SYMBOLINFO
DESCRIPTOR.message_types_by_name['CommSymbolInfo'] = _COMMSYMBOLINFO
DESCRIPTOR.message_types_by_name['CommSymbolInfos'] = _COMMSYMBOLINFOS
DESCRIPTOR.message_types_by_name['StrategyTemplate'] = _STRATEGYTEMPLATE
DESCRIPTOR.message_types_by_name['StrategyTemplateItem'] = _STRATEGYTEMPLATEITEM
DESCRIPTOR.message_types_by_name['StrategyTemplateItems'] = _STRATEGYTEMPLATEITEMS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), dict(
  DESCRIPTOR = _PROPERTY,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Property)
  ))
_sym_db.RegisterMessage(Property)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), dict(
  DESCRIPTOR = _FILTER,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Filter)
  ))
_sym_db.RegisterMessage(Filter)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Error)
  ))
_sym_db.RegisterMessage(Error)

ConnectionAddress = _reflection.GeneratedProtocolMessageType('ConnectionAddress', (_message.Message,), dict(

  AddressEntry = _reflection.GeneratedProtocolMessageType('AddressEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONNECTIONADDRESS_ADDRESSENTRY,
    __module__ = 'core.api.common_pb2'
    # @@protoc_insertion_point(class_scope:core.api.ConnectionAddress.AddressEntry)
    ))
  ,
  DESCRIPTOR = _CONNECTIONADDRESS,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ConnectionAddress)
  ))
_sym_db.RegisterMessage(ConnectionAddress)
_sym_db.RegisterMessage(ConnectionAddress.AddressEntry)

ConnectionStatus = _reflection.GeneratedProtocolMessageType('ConnectionStatus', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONSTATUS,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ConnectionStatus)
  ))
_sym_db.RegisterMessage(ConnectionStatus)

Log = _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), dict(
  DESCRIPTOR = _LOG,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Log)
  ))
_sym_db.RegisterMessage(Log)

Logs = _reflection.GeneratedProtocolMessageType('Logs', (_message.Message,), dict(
  DESCRIPTOR = _LOGS,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Logs)
  ))
_sym_db.RegisterMessage(Logs)

Heartbeat = _reflection.GeneratedProtocolMessageType('Heartbeat', (_message.Message,), dict(
  DESCRIPTOR = _HEARTBEAT,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.Heartbeat)
  ))
_sym_db.RegisterMessage(Heartbeat)

SymbolInfo = _reflection.GeneratedProtocolMessageType('SymbolInfo', (_message.Message,), dict(
  DESCRIPTOR = _SYMBOLINFO,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.SymbolInfo)
  ))
_sym_db.RegisterMessage(SymbolInfo)

CommSymbolInfo = _reflection.GeneratedProtocolMessageType('CommSymbolInfo', (_message.Message,), dict(
  DESCRIPTOR = _COMMSYMBOLINFO,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.CommSymbolInfo)
  ))
_sym_db.RegisterMessage(CommSymbolInfo)

CommSymbolInfos = _reflection.GeneratedProtocolMessageType('CommSymbolInfos', (_message.Message,), dict(
  DESCRIPTOR = _COMMSYMBOLINFOS,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.CommSymbolInfos)
  ))
_sym_db.RegisterMessage(CommSymbolInfos)

StrategyTemplate = _reflection.GeneratedProtocolMessageType('StrategyTemplate', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYTEMPLATE,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.StrategyTemplate)
  ))
_sym_db.RegisterMessage(StrategyTemplate)

StrategyTemplateItem = _reflection.GeneratedProtocolMessageType('StrategyTemplateItem', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYTEMPLATEITEM,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.StrategyTemplateItem)
  ))
_sym_db.RegisterMessage(StrategyTemplateItem)

StrategyTemplateItems = _reflection.GeneratedProtocolMessageType('StrategyTemplateItems', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYTEMPLATEITEMS,
  __module__ = 'core.api.common_pb2'
  # @@protoc_insertion_point(class_scope:core.api.StrategyTemplateItems)
  ))
_sym_db.RegisterMessage(StrategyTemplateItems)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z(nextfin.com/nfplatform/core/api;core_api'))
_CONNECTIONADDRESS_ADDRESSENTRY.has_options = True
_CONNECTIONADDRESS_ADDRESSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_LOG.fields_by_name['created_at'].has_options = True
_LOG.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))
_HEARTBEAT.fields_by_name['created_at'].has_options = True
_HEARTBEAT.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_SYMBOLINFO.fields_by_name['listing_date'].has_options = True
_SYMBOLINFO.fields_by_name['listing_date']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_SYMBOLINFO.fields_by_name['settle_date'].has_options = True
_SYMBOLINFO.fields_by_name['settle_date']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
# @@protoc_insertion_point(module_scope)
