# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strategy/api/strategy.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.api import common_pb2 as core_dot_api_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strategy/api/strategy.proto',
  package='strategy.api',
  syntax='proto3',
  serialized_pb=_b('\n\x1bstrategy/api/strategy.proto\x12\x0cstrategy.api\x1a\x15\x63ore/api/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"\x95\x04\n\x08Strategy\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05intro\x18\x03 \x01(\t\x12\x10\n\x08language\x18\x04 \x01(\t\x12\r\n\x05stage\x18\x05 \x01(\x05\x12)\n\nparam_mode\x18\x08 \x01(\x05\x42\x15\xf2\xde\x1f\x11xorm:\"default(0)\"\x12\x12\n\nparam_info\x18\t \x01(\t\x12\x13\n\x0btemplate_id\x18\n \x01(\t\x12\'\n\x08stg_type\x18\x0b \x01(\x05\x42\x15\xf2\xde\x1f\x11xorm:\"default(0)\"\x12\x10\n\x08\x65xchange\x18\x0c \x01(\t\x12\r\n\x05\x66ront\x18\r \x01(\t\x12\x0c\n\x04rear\x18\x0e \x01(\t\x12\x0f\n\x07vol_sum\x18\x0f \x01(\t\x12\x13\n\x0bruntime_sum\x18\x10 \x01(\t\x12\x46\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x16\x90\xdf\x1f\x01\xf2\xde\x1f\x0exorm:\"created\"\x12\x46\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x16\x90\xdf\x1f\x01\xf2\xde\x1f\x0exorm:\"updated\"\"T\n\x05Stage\x12\x11\n\rStage_Unknown\x10\x00\x12\x12\n\x0eStage_Backtest\x10\x01\x12\x14\n\x10Stage_Simulation\x10\x02\x12\x0e\n\nStage_Live\x10\x03\"\xae\x01\n\x0bStrategyRds\x12\n\n\x02Id\x18\x01 \x01(\x03\x12\x13\n\x0bstrategy_id\x18\x02 \x01(\t\x12\x11\n\ttype_name\x18\x03 \x01(\t\x12\x11\n\trds_value\x18\x04 \x01(\x01\x12\x10\n\x08rds_info\x18\x05 \x01(\t\x12\x46\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x16\x90\xdf\x1f\x01\xf2\xde\x1f\x0exorm:\"created\"\"2\n\nStrategies\x12$\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x16.strategy.api.Strategy\"Q\n\x0eStrategyStatus\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12*\n\x06status\x18\x02 \x01(\x0b\x32\x1a.core.api.ConnectionStatus\">\n\x10StrategyStatuses\x12*\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1c.strategy.api.StrategyStatus\"I\n\x0bStopCommand\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\x05\x12\x15\n\rreason_detail\x18\x03 \x01(\t\"\x8e\x01\n\x0cStartCommand\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\x12\x11\n\tdirectory\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x18\n\x10interpreter_path\x18\x05 \x01(\t\x12\x1d\n\x15interpreter_venv_path\x18\x06 \x01(\t\"9\n\rStartCommands\x12(\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1a.strategy.api.StartCommandB2Z0nextfin.com/nfplatform/strategy/api;strategy_apib\x06proto3')
  ,
  dependencies=[core_dot_api_dot_common__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])



_STRATEGY_STAGE = _descriptor.EnumDescriptor(
  name='Stage',
  full_name='strategy.api.Strategy.Stage',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Stage_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Stage_Backtest', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Stage_Simulation', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Stage_Live', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=573,
  serialized_end=657,
)
_sym_db.RegisterEnumDescriptor(_STRATEGY_STAGE)


_STRATEGY = _descriptor.Descriptor(
  name='Strategy',
  full_name='strategy.api.Strategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.Strategy.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='strategy.api.Strategy.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='intro', full_name='strategy.api.Strategy.intro', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='strategy.api.Strategy.language', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stage', full_name='strategy.api.Strategy.stage', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param_mode', full_name='strategy.api.Strategy.param_mode', index=5,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\021xorm:\"default(0)\"'))),
    _descriptor.FieldDescriptor(
      name='param_info', full_name='strategy.api.Strategy.param_info', index=6,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='template_id', full_name='strategy.api.Strategy.template_id', index=7,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stg_type', full_name='strategy.api.Strategy.stg_type', index=8,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\021xorm:\"default(0)\"'))),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='strategy.api.Strategy.exchange', index=9,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='strategy.api.Strategy.front', index=10,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='strategy.api.Strategy.rear', index=11,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vol_sum', full_name='strategy.api.Strategy.vol_sum', index=12,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='runtime_sum', full_name='strategy.api.Strategy.runtime_sum', index=13,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='strategy.api.Strategy.created_at', index=14,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='strategy.api.Strategy.updated_at', index=15,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"updated\"'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STRATEGY_STAGE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=657,
)


_STRATEGYRDS = _descriptor.Descriptor(
  name='StrategyRds',
  full_name='strategy.api.StrategyRds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Id', full_name='strategy.api.StrategyRds.Id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.StrategyRds.strategy_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type_name', full_name='strategy.api.StrategyRds.type_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rds_value', full_name='strategy.api.StrategyRds.rds_value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rds_info', full_name='strategy.api.StrategyRds.rds_info', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='strategy.api.StrategyRds.created_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=834,
)


_STRATEGIES = _descriptor.Descriptor(
  name='Strategies',
  full_name='strategy.api.Strategies',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='strategy.api.Strategies.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=886,
)


_STRATEGYSTATUS = _descriptor.Descriptor(
  name='StrategyStatus',
  full_name='strategy.api.StrategyStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.StrategyStatus.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='strategy.api.StrategyStatus.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=888,
  serialized_end=969,
)


_STRATEGYSTATUSES = _descriptor.Descriptor(
  name='StrategyStatuses',
  full_name='strategy.api.StrategyStatuses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='strategy.api.StrategyStatuses.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1033,
)


_STOPCOMMAND = _descriptor.Descriptor(
  name='StopCommand',
  full_name='strategy.api.StopCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.StopCommand.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='strategy.api.StopCommand.reason', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason_detail', full_name='strategy.api.StopCommand.reason_detail', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1108,
)


_STARTCOMMAND = _descriptor.Descriptor(
  name='StartCommand',
  full_name='strategy.api.StartCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.StartCommand.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command', full_name='strategy.api.StartCommand.command', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='directory', full_name='strategy.api.StartCommand.directory', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='path', full_name='strategy.api.StartCommand.path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interpreter_path', full_name='strategy.api.StartCommand.interpreter_path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interpreter_venv_path', full_name='strategy.api.StartCommand.interpreter_venv_path', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1253,
)


_STARTCOMMANDS = _descriptor.Descriptor(
  name='StartCommands',
  full_name='strategy.api.StartCommands',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='strategy.api.StartCommands.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1255,
  serialized_end=1312,
)

_STRATEGY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STRATEGY.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STRATEGY_STAGE.containing_type = _STRATEGY
_STRATEGYRDS.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STRATEGIES.fields_by_name['data'].message_type = _STRATEGY
_STRATEGYSTATUS.fields_by_name['status'].message_type = core_dot_api_dot_common__pb2._CONNECTIONSTATUS
_STRATEGYSTATUSES.fields_by_name['data'].message_type = _STRATEGYSTATUS
_STARTCOMMANDS.fields_by_name['data'].message_type = _STARTCOMMAND
DESCRIPTOR.message_types_by_name['Strategy'] = _STRATEGY
DESCRIPTOR.message_types_by_name['StrategyRds'] = _STRATEGYRDS
DESCRIPTOR.message_types_by_name['Strategies'] = _STRATEGIES
DESCRIPTOR.message_types_by_name['StrategyStatus'] = _STRATEGYSTATUS
DESCRIPTOR.message_types_by_name['StrategyStatuses'] = _STRATEGYSTATUSES
DESCRIPTOR.message_types_by_name['StopCommand'] = _STOPCOMMAND
DESCRIPTOR.message_types_by_name['StartCommand'] = _STARTCOMMAND
DESCRIPTOR.message_types_by_name['StartCommands'] = _STARTCOMMANDS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Strategy = _reflection.GeneratedProtocolMessageType('Strategy', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGY,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.Strategy)
  ))
_sym_db.RegisterMessage(Strategy)

StrategyRds = _reflection.GeneratedProtocolMessageType('StrategyRds', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYRDS,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StrategyRds)
  ))
_sym_db.RegisterMessage(StrategyRds)

Strategies = _reflection.GeneratedProtocolMessageType('Strategies', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGIES,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.Strategies)
  ))
_sym_db.RegisterMessage(Strategies)

StrategyStatus = _reflection.GeneratedProtocolMessageType('StrategyStatus', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYSTATUS,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StrategyStatus)
  ))
_sym_db.RegisterMessage(StrategyStatus)

StrategyStatuses = _reflection.GeneratedProtocolMessageType('StrategyStatuses', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYSTATUSES,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StrategyStatuses)
  ))
_sym_db.RegisterMessage(StrategyStatuses)

StopCommand = _reflection.GeneratedProtocolMessageType('StopCommand', (_message.Message,), dict(
  DESCRIPTOR = _STOPCOMMAND,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StopCommand)
  ))
_sym_db.RegisterMessage(StopCommand)

StartCommand = _reflection.GeneratedProtocolMessageType('StartCommand', (_message.Message,), dict(
  DESCRIPTOR = _STARTCOMMAND,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StartCommand)
  ))
_sym_db.RegisterMessage(StartCommand)

StartCommands = _reflection.GeneratedProtocolMessageType('StartCommands', (_message.Message,), dict(
  DESCRIPTOR = _STARTCOMMANDS,
  __module__ = 'strategy.api.strategy_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StartCommands)
  ))
_sym_db.RegisterMessage(StartCommands)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z0nextfin.com/nfplatform/strategy/api;strategy_api'))
_STRATEGY.fields_by_name['param_mode'].has_options = True
_STRATEGY.fields_by_name['param_mode']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\021xorm:\"default(0)\"'))
_STRATEGY.fields_by_name['stg_type'].has_options = True
_STRATEGY.fields_by_name['stg_type']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\336\037\021xorm:\"default(0)\"'))
_STRATEGY.fields_by_name['created_at'].has_options = True
_STRATEGY.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))
_STRATEGY.fields_by_name['updated_at'].has_options = True
_STRATEGY.fields_by_name['updated_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"updated\"'))
_STRATEGYRDS.fields_by_name['created_at'].has_options = True
_STRATEGYRDS.fields_by_name['created_at']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001\362\336\037\016xorm:\"created\"'))
# @@protoc_insertion_point(module_scope)
