# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strategy/api/strategy.service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.api import common_pb2 as core_dot_api_dot_common__pb2
from strategy.api import strategy_pb2 as strategy_dot_api_dot_strategy__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strategy/api/strategy.service.proto',
  package='strategy.api',
  syntax='proto3',
  serialized_pb=_b('\n#strategy/api/strategy.service.proto\x12\x0cstrategy.api\x1a\x15\x63ore/api/common.proto\x1a\x1bstrategy/api/strategy.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"Y\n\x0eSetAccountsReq\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\r\n\x05stage\x18\x02 \x01(\x05\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x03 \x03(\t\x12\x0e\n\x06market\x18\x04 \x01(\t\"4\n\x0eGetAccountsReq\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\r\n\x05stage\x18\x02 \x01(\x05\"%\n\x0eGetAccountsRsp\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\t\"/\n\x19GetStrategiesToAccountReq\x12\x12\n\naccount_id\x18\x01 \x01(\t\"J\n\x10GetStrategiesReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x14\n\x0cstrategy_ids\x18\x02 \x03(\t\"]\n\x17GetStrategiesOfStageReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x0e\n\x06stages\x18\x02 \x03(\x05\x12\x10\n\x08stg_type\x18\x03 \x01(\x05\"(\n\x10\x44\x65lStrategiesReq\x12\x14\n\x0cstrategy_ids\x18\x01 \x03(\t\"M\n\x13GetStartCommandsReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x14\n\x0cstrategy_ids\x18\x02 \x03(\t\"P\n\x16GetStrategyStatusesReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x14\n\x0cstrategy_ids\x18\x02 \x03(\t\"K\n\x12GetStrategyLogsReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x13\n\x0bstrategy_id\x18\x02 \x01(\t\"5\n\x0eStrategySignal\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x0e\n\x06signal\x18\x02 \x01(\x05\"\x82\x01\n\x12\x41\x64\x64\x42indStrategyReq\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x01 \x03(\t\x12(\n\x08strategy\x18\x02 \x01(\x0b\x32\x16.strategy.api.Strategy\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\r\n\x05\x66ront\x18\x04 \x01(\t\x12\x0c\n\x04rear\x18\x05 \x01(\t\"(\n\x11GetstrategyRdsReq\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\"<\n\x11GetstrategyRdsRsp\x12\'\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x19.strategy.api.StrategyRds2\x81\x11\n\x0fStrategyService\x12X\n\x0b\x41\x64\x64Strategy\x12\x16.strategy.api.Strategy\x1a\x16.strategy.api.Strategy\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v3/strategies:\x01*\x12i\n\x0f\x41\x64\x64\x42indStrategy\x12 .strategy.api.AddBindStrategyReq\x1a\x16.strategy.api.Strategy\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v3/strategies-ab:\x01*\x12m\n\tEditParam\x12\x16.strategy.api.Strategy\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\"%/v3/strategieparam/{strategy_id}/edit:\x01*\x12\x61\n\rGetStrategies\x12\x1e.strategy.api.GetStrategiesReq\x1a\x18.strategy.api.Strategies\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v3/strategies\x12x\n\x14GetStrategiesOfStage\x12%.strategy.api.GetStrategiesOfStageReq\x1a\x18.strategy.api.Strategies\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v3/strategies-of-stage\x12\x66\n\x0bSetStrategy\x12\x16.strategy.api.Strategy\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v3/strategies/{strategy_id}:\x01*\x12y\n\x11SetStrategySignal\x12\x1c.strategy.api.StrategySignal\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(\"#/v3/strategies/{strategy_id}/signal:\x01*\x12i\n\rDelStrategies\x12\x1e.strategy.api.DelStrategiesReq\x1a\x16.google.protobuf.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v3/strategies-delete:\x01*\x12u\n\x0bSetAccounts\x12\x1c.strategy.api.SetAccountsReq\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\"%/v3/strategies/{strategy_id}/accounts:\x01*\x12x\n\x0bGetAccounts\x12\x1c.strategy.api.GetAccountsReq\x1a\x1c.strategy.api.GetAccountsRsp\"-\x82\xd3\xe4\x93\x02\'\x12%/v3/strategies/{strategy_id}/accounts\x12\x8b\x01\n\x16GetStrategiesToAccount\x12\'.strategy.api.GetStrategiesToAccountReq\x1a\x18.strategy.api.Strategies\".\x82\xd3\xe4\x93\x02(\x12&/v3/strategies-to-account/{account_id}\x12z\n\x13GetStrategyStatuses\x12$.strategy.api.GetStrategyStatusesReq\x1a\x1e.strategy.api.StrategyStatuses\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v3/strategy-statuses\x12o\n\x13SetStrategyStatuses\x12\x1e.strategy.api.StrategyStatuses\x1a\x16.google.protobuf.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v3/strategy-statuses:\x01*\x12v\n\x0cStopStrategy\x12\x19.strategy.api.StopCommand\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-\"(/v3/strategy-commands/{strategy_id}/stop:\x01*\x12q\n\x10GetStartCommands\x12!.strategy.api.GetStartCommandsReq\x1a\x1b.strategy.api.StartCommands\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v3/strategy-commands\x12u\n\x0fSetStartCommand\x12\x1a.strategy.api.StartCommand\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(\x1a#/v3/strategy-commands/{strategy_id}:\x01*\x12W\n\x0f\x41\x64\x64StrategyLogs\x12\x0e.core.api.Logs\x1a\x16.google.protobuf.Empty\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v3/strategy-logs:\x01*\x12l\n\x0fGetStrategyLogs\x12 .strategy.api.GetStrategyLogsReq\x1a\x0e.core.api.Logs\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v3/strategy-logs/{strategy_id}\x12z\n\x0eGetstrategyRds\x12\x1f.strategy.api.GetstrategyRdsReq\x1a\x1f.strategy.api.GetstrategyRdsRsp\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v3/strategy-rds/{strategy_id}B2Z0nextfin.com/nfplatform/strategy/api;strategy_apib\x06proto3')
  ,
  dependencies=[core_dot_api_dot_common__pb2.DESCRIPTOR,strategy_dot_api_dot_strategy__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_SETACCOUNTSREQ = _descriptor.Descriptor(
  name='SetAccountsReq',
  full_name='strategy.api.SetAccountsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.SetAccountsReq.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stage', full_name='strategy.api.SetAccountsReq.stage', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='strategy.api.SetAccountsReq.account_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='market', full_name='strategy.api.SetAccountsReq.market', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=253,
)


_GETACCOUNTSREQ = _descriptor.Descriptor(
  name='GetAccountsReq',
  full_name='strategy.api.GetAccountsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.GetAccountsReq.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stage', full_name='strategy.api.GetAccountsReq.stage', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=255,
  serialized_end=307,
)


_GETACCOUNTSRSP = _descriptor.Descriptor(
  name='GetAccountsRsp',
  full_name='strategy.api.GetAccountsRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='strategy.api.GetAccountsRsp.account_ids', index=0,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=309,
  serialized_end=346,
)


_GETSTRATEGIESTOACCOUNTREQ = _descriptor.Descriptor(
  name='GetStrategiesToAccountReq',
  full_name='strategy.api.GetStrategiesToAccountReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='strategy.api.GetStrategiesToAccountReq.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=395,
)


_GETSTRATEGIESREQ = _descriptor.Descriptor(
  name='GetStrategiesReq',
  full_name='strategy.api.GetStrategiesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='strategy.api.GetStrategiesReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_ids', full_name='strategy.api.GetStrategiesReq.strategy_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=471,
)


_GETSTRATEGIESOFSTAGEREQ = _descriptor.Descriptor(
  name='GetStrategiesOfStageReq',
  full_name='strategy.api.GetStrategiesOfStageReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='strategy.api.GetStrategiesOfStageReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stages', full_name='strategy.api.GetStrategiesOfStageReq.stages', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stg_type', full_name='strategy.api.GetStrategiesOfStageReq.stg_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=566,
)


_DELSTRATEGIESREQ = _descriptor.Descriptor(
  name='DelStrategiesReq',
  full_name='strategy.api.DelStrategiesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_ids', full_name='strategy.api.DelStrategiesReq.strategy_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=608,
)


_GETSTARTCOMMANDSREQ = _descriptor.Descriptor(
  name='GetStartCommandsReq',
  full_name='strategy.api.GetStartCommandsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='strategy.api.GetStartCommandsReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_ids', full_name='strategy.api.GetStartCommandsReq.strategy_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=610,
  serialized_end=687,
)


_GETSTRATEGYSTATUSESREQ = _descriptor.Descriptor(
  name='GetStrategyStatusesReq',
  full_name='strategy.api.GetStrategyStatusesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='strategy.api.GetStrategyStatusesReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_ids', full_name='strategy.api.GetStrategyStatusesReq.strategy_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=689,
  serialized_end=769,
)


_GETSTRATEGYLOGSREQ = _descriptor.Descriptor(
  name='GetStrategyLogsReq',
  full_name='strategy.api.GetStrategyLogsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='strategy.api.GetStrategyLogsReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.GetStrategyLogsReq.strategy_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=846,
)


_STRATEGYSIGNAL = _descriptor.Descriptor(
  name='StrategySignal',
  full_name='strategy.api.StrategySignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.StrategySignal.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signal', full_name='strategy.api.StrategySignal.signal', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=848,
  serialized_end=901,
)


_ADDBINDSTRATEGYREQ = _descriptor.Descriptor(
  name='AddBindStrategyReq',
  full_name='strategy.api.AddBindStrategyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='strategy.api.AddBindStrategyReq.account_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy', full_name='strategy.api.AddBindStrategyReq.strategy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='strategy.api.AddBindStrategyReq.exchange', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='strategy.api.AddBindStrategyReq.front', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='strategy.api.AddBindStrategyReq.rear', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=904,
  serialized_end=1034,
)


_GETSTRATEGYRDSREQ = _descriptor.Descriptor(
  name='GetstrategyRdsReq',
  full_name='strategy.api.GetstrategyRdsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='strategy.api.GetstrategyRdsReq.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1036,
  serialized_end=1076,
)


_GETSTRATEGYRDSRSP = _descriptor.Descriptor(
  name='GetstrategyRdsRsp',
  full_name='strategy.api.GetstrategyRdsRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='strategy.api.GetstrategyRdsRsp.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1138,
)

_GETSTRATEGIESREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETSTRATEGIESOFSTAGEREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETSTARTCOMMANDSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETSTRATEGYSTATUSESREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETSTRATEGYLOGSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_ADDBINDSTRATEGYREQ.fields_by_name['strategy'].message_type = strategy_dot_api_dot_strategy__pb2._STRATEGY
_GETSTRATEGYRDSRSP.fields_by_name['data'].message_type = strategy_dot_api_dot_strategy__pb2._STRATEGYRDS
DESCRIPTOR.message_types_by_name['SetAccountsReq'] = _SETACCOUNTSREQ
DESCRIPTOR.message_types_by_name['GetAccountsReq'] = _GETACCOUNTSREQ
DESCRIPTOR.message_types_by_name['GetAccountsRsp'] = _GETACCOUNTSRSP
DESCRIPTOR.message_types_by_name['GetStrategiesToAccountReq'] = _GETSTRATEGIESTOACCOUNTREQ
DESCRIPTOR.message_types_by_name['GetStrategiesReq'] = _GETSTRATEGIESREQ
DESCRIPTOR.message_types_by_name['GetStrategiesOfStageReq'] = _GETSTRATEGIESOFSTAGEREQ
DESCRIPTOR.message_types_by_name['DelStrategiesReq'] = _DELSTRATEGIESREQ
DESCRIPTOR.message_types_by_name['GetStartCommandsReq'] = _GETSTARTCOMMANDSREQ
DESCRIPTOR.message_types_by_name['GetStrategyStatusesReq'] = _GETSTRATEGYSTATUSESREQ
DESCRIPTOR.message_types_by_name['GetStrategyLogsReq'] = _GETSTRATEGYLOGSREQ
DESCRIPTOR.message_types_by_name['StrategySignal'] = _STRATEGYSIGNAL
DESCRIPTOR.message_types_by_name['AddBindStrategyReq'] = _ADDBINDSTRATEGYREQ
DESCRIPTOR.message_types_by_name['GetstrategyRdsReq'] = _GETSTRATEGYRDSREQ
DESCRIPTOR.message_types_by_name['GetstrategyRdsRsp'] = _GETSTRATEGYRDSRSP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetAccountsReq = _reflection.GeneratedProtocolMessageType('SetAccountsReq', (_message.Message,), dict(
  DESCRIPTOR = _SETACCOUNTSREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.SetAccountsReq)
  ))
_sym_db.RegisterMessage(SetAccountsReq)

GetAccountsReq = _reflection.GeneratedProtocolMessageType('GetAccountsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTSREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetAccountsReq)
  ))
_sym_db.RegisterMessage(GetAccountsReq)

GetAccountsRsp = _reflection.GeneratedProtocolMessageType('GetAccountsRsp', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTSRSP,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetAccountsRsp)
  ))
_sym_db.RegisterMessage(GetAccountsRsp)

GetStrategiesToAccountReq = _reflection.GeneratedProtocolMessageType('GetStrategiesToAccountReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGIESTOACCOUNTREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStrategiesToAccountReq)
  ))
_sym_db.RegisterMessage(GetStrategiesToAccountReq)

GetStrategiesReq = _reflection.GeneratedProtocolMessageType('GetStrategiesReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGIESREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStrategiesReq)
  ))
_sym_db.RegisterMessage(GetStrategiesReq)

GetStrategiesOfStageReq = _reflection.GeneratedProtocolMessageType('GetStrategiesOfStageReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGIESOFSTAGEREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStrategiesOfStageReq)
  ))
_sym_db.RegisterMessage(GetStrategiesOfStageReq)

DelStrategiesReq = _reflection.GeneratedProtocolMessageType('DelStrategiesReq', (_message.Message,), dict(
  DESCRIPTOR = _DELSTRATEGIESREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.DelStrategiesReq)
  ))
_sym_db.RegisterMessage(DelStrategiesReq)

GetStartCommandsReq = _reflection.GeneratedProtocolMessageType('GetStartCommandsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTARTCOMMANDSREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStartCommandsReq)
  ))
_sym_db.RegisterMessage(GetStartCommandsReq)

GetStrategyStatusesReq = _reflection.GeneratedProtocolMessageType('GetStrategyStatusesReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGYSTATUSESREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStrategyStatusesReq)
  ))
_sym_db.RegisterMessage(GetStrategyStatusesReq)

GetStrategyLogsReq = _reflection.GeneratedProtocolMessageType('GetStrategyLogsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGYLOGSREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetStrategyLogsReq)
  ))
_sym_db.RegisterMessage(GetStrategyLogsReq)

StrategySignal = _reflection.GeneratedProtocolMessageType('StrategySignal', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYSIGNAL,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.StrategySignal)
  ))
_sym_db.RegisterMessage(StrategySignal)

AddBindStrategyReq = _reflection.GeneratedProtocolMessageType('AddBindStrategyReq', (_message.Message,), dict(
  DESCRIPTOR = _ADDBINDSTRATEGYREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.AddBindStrategyReq)
  ))
_sym_db.RegisterMessage(AddBindStrategyReq)

GetstrategyRdsReq = _reflection.GeneratedProtocolMessageType('GetstrategyRdsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGYRDSREQ,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetstrategyRdsReq)
  ))
_sym_db.RegisterMessage(GetstrategyRdsReq)

GetstrategyRdsRsp = _reflection.GeneratedProtocolMessageType('GetstrategyRdsRsp', (_message.Message,), dict(
  DESCRIPTOR = _GETSTRATEGYRDSRSP,
  __module__ = 'strategy.api.strategy.service_pb2'
  # @@protoc_insertion_point(class_scope:strategy.api.GetstrategyRdsRsp)
  ))
_sym_db.RegisterMessage(GetstrategyRdsRsp)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z0nextfin.com/nfplatform/strategy/api;strategy_api'))

_STRATEGYSERVICE = _descriptor.ServiceDescriptor(
  name='StrategyService',
  full_name='strategy.api.StrategyService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=1141,
  serialized_end=3318,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddStrategy',
    full_name='strategy.api.StrategyService.AddStrategy',
    index=0,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STRATEGY,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\023\"\016/v3/strategies:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='AddBindStrategy',
    full_name='strategy.api.StrategyService.AddBindStrategy',
    index=1,
    containing_service=None,
    input_type=_ADDBINDSTRATEGYREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\026\"\021/v3/strategies-ab:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='EditParam',
    full_name='strategy.api.StrategyService.EditParam',
    index=2,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STRATEGY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002*\"%/v3/strategieparam/{strategy_id}/edit:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategies',
    full_name='strategy.api.StrategyService.GetStrategies',
    index=3,
    containing_service=None,
    input_type=_GETSTRATEGIESREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGIES,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\020\022\016/v3/strategies')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategiesOfStage',
    full_name='strategy.api.StrategyService.GetStrategiesOfStage',
    index=4,
    containing_service=None,
    input_type=_GETSTRATEGIESOFSTAGEREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGIES,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\031\022\027/v3/strategies-of-stage')),
  ),
  _descriptor.MethodDescriptor(
    name='SetStrategy',
    full_name='strategy.api.StrategyService.SetStrategy',
    index=5,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STRATEGY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002!\"\034/v3/strategies/{strategy_id}:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='SetStrategySignal',
    full_name='strategy.api.StrategyService.SetStrategySignal',
    index=6,
    containing_service=None,
    input_type=_STRATEGYSIGNAL,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002(\"#/v3/strategies/{strategy_id}/signal:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='DelStrategies',
    full_name='strategy.api.StrategyService.DelStrategies',
    index=7,
    containing_service=None,
    input_type=_DELSTRATEGIESREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\032\"\025/v3/strategies-delete:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='SetAccounts',
    full_name='strategy.api.StrategyService.SetAccounts',
    index=8,
    containing_service=None,
    input_type=_SETACCOUNTSREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002*\"%/v3/strategies/{strategy_id}/accounts:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetAccounts',
    full_name='strategy.api.StrategyService.GetAccounts',
    index=9,
    containing_service=None,
    input_type=_GETACCOUNTSREQ,
    output_type=_GETACCOUNTSRSP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\'\022%/v3/strategies/{strategy_id}/accounts')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategiesToAccount',
    full_name='strategy.api.StrategyService.GetStrategiesToAccount',
    index=10,
    containing_service=None,
    input_type=_GETSTRATEGIESTOACCOUNTREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGIES,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002(\022&/v3/strategies-to-account/{account_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategyStatuses',
    full_name='strategy.api.StrategyService.GetStrategyStatuses',
    index=11,
    containing_service=None,
    input_type=_GETSTRATEGYSTATUSESREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STRATEGYSTATUSES,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\027\022\025/v3/strategy-statuses')),
  ),
  _descriptor.MethodDescriptor(
    name='SetStrategyStatuses',
    full_name='strategy.api.StrategyService.SetStrategyStatuses',
    index=12,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STRATEGYSTATUSES,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\032\"\025/v3/strategy-statuses:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='StopStrategy',
    full_name='strategy.api.StrategyService.StopStrategy',
    index=13,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STOPCOMMAND,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002-\"(/v3/strategy-commands/{strategy_id}/stop:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStartCommands',
    full_name='strategy.api.StrategyService.GetStartCommands',
    index=14,
    containing_service=None,
    input_type=_GETSTARTCOMMANDSREQ,
    output_type=strategy_dot_api_dot_strategy__pb2._STARTCOMMANDS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\027\022\025/v3/strategy-commands')),
  ),
  _descriptor.MethodDescriptor(
    name='SetStartCommand',
    full_name='strategy.api.StrategyService.SetStartCommand',
    index=15,
    containing_service=None,
    input_type=strategy_dot_api_dot_strategy__pb2._STARTCOMMAND,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002(\032#/v3/strategy-commands/{strategy_id}:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='AddStrategyLogs',
    full_name='strategy.api.StrategyService.AddStrategyLogs',
    index=16,
    containing_service=None,
    input_type=core_dot_api_dot_common__pb2._LOGS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\026\"\021/v3/strategy-logs:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategyLogs',
    full_name='strategy.api.StrategyService.GetStrategyLogs',
    index=17,
    containing_service=None,
    input_type=_GETSTRATEGYLOGSREQ,
    output_type=core_dot_api_dot_common__pb2._LOGS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002!\022\037/v3/strategy-logs/{strategy_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetstrategyRds',
    full_name='strategy.api.StrategyService.GetstrategyRds',
    index=18,
    containing_service=None,
    input_type=_GETSTRATEGYRDSREQ,
    output_type=_GETSTRATEGYRDSRSP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002 \022\036/v3/strategy-rds/{strategy_id}')),
  ),
])
_sym_db.RegisterServiceDescriptor(_STRATEGYSERVICE)

DESCRIPTOR.services_by_name['StrategyService'] = _STRATEGYSERVICE

# @@protoc_insertion_point(module_scope)
