# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tradegw/api/tradegw.service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.api import common_pb2 as core_dot_api_dot_common__pb2
from core.api import account_pb2 as core_dot_api_dot_account__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tradegw/api/tradegw.service.proto',
  package='tradegw.api',
  syntax='proto3',
  serialized_pb=_b('\n!tradegw/api/tradegw.service.proto\x12\x0btradegw.api\x1a\x15\x63ore/api/common.proto\x1a\x16\x63ore/api/account.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x14gogoproto/gogo.proto\"Q\n\x18GetAccountConnectionsReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\t\"/\n\x18\x44\x65lAccountConnectionsReq\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x01 \x03(\t\"G\n\x0eGetAccountsReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\t\"#\n\rDelAccountReq\x12\x12\n\naccount_id\x18\x01 \x01(\t\"N\n\x15GetAccountStatusesReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\t\">\n\x15SetAccountCumInoutReq\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x11\n\tcum_inout\x18\x02 \x01(\x01\"h\n\rGetAccountReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x12\n\napi_secret\x18\x05 \x01(\t\"\xac\x01\n\x14GetSysMessageListReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12&\n\x07m_level\x18\x02 \x01(\x0e\x32\x15.core.api.SysMsgLevel\x12$\n\x06m_type\x18\x03 \x01(\x0e\x32\x14.core.api.SysMsgType\x12\x12\n\nstart_time\x18\x04 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\x03\"\x87\x01\n\x16GetTradeMessageListReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x13\n\x0bstrategy_id\x18\x03 \x01(\t\x12\x12\n\nstart_time\x18\x04 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\x03\"\x89\x01\n\x18GetExecrptMessageListReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x13\n\x0bstrategy_id\x18\x03 \x01(\t\x12\x12\n\nstart_time\x18\x04 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\x03\x32\xee\x06\n\x0eTradegwService\x12t\n\x14\x41\x64\x64\x41\x63\x63ountConnection\x12\x1b.core.api.AccountConnection\x1a\x1b.core.api.AccountConnection\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v3/account-connections:\x01*\x12}\n\x15GetAccountConnections\x12%.tradegw.api.GetAccountConnectionsReq\x1a\x1c.core.api.AccountConnections\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v3/account-connections\x12\x81\x01\n\x15\x44\x65lAccountConnections\x12%.tradegw.api.DelAccountConnectionsReq\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#\"\x1e/v3/account-connections/delete:\x01*\x12\x80\x01\n\x0fGetOrderSummary\x12%.tradegw.api.DelAccountConnectionsReq\x1a\x19.core.api.OrderSummaryNum\"+\x82\xd3\xe4\x93\x02%\x12#/v3/account-trade/get-order-summary\x12t\n\x13GetTradeMessageList\x12#.tradegw.api.GetTradeMessageListReq\x1a\x1a.core.api.TradeMessageList\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v3/trademsg/list:\x01*\x12|\n\x15GetExecrptMessageList\x12%.tradegw.api.GetExecrptMessageListReq\x1a\x1c.core.api.ExecrptMessageList\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v3/execrptmsg/list:\x01*\x12l\n\x11GetSysMessageList\x12!.tradegw.api.GetSysMessageListReq\x1a\x18.core.api.SysMessageList\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v3/sysmsg/list:\x01*B0Z.nextfin.com/nfplatform/tradegw/api;tradegw_apib\x06proto3')
  ,
  dependencies=[core_dot_api_dot_common__pb2.DESCRIPTOR,core_dot_api_dot_account__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_GETACCOUNTCONNECTIONSREQ = _descriptor.Descriptor(
  name='GetAccountConnectionsReq',
  full_name='tradegw.api.GetAccountConnectionsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='tradegw.api.GetAccountConnectionsReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='tradegw.api.GetAccountConnectionsReq.account_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=259,
)


_DELACCOUNTCONNECTIONSREQ = _descriptor.Descriptor(
  name='DelAccountConnectionsReq',
  full_name='tradegw.api.DelAccountConnectionsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='tradegw.api.DelAccountConnectionsReq.account_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=308,
)


_GETACCOUNTSREQ = _descriptor.Descriptor(
  name='GetAccountsReq',
  full_name='tradegw.api.GetAccountsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='tradegw.api.GetAccountsReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='tradegw.api.GetAccountsReq.account_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=381,
)


_DELACCOUNTREQ = _descriptor.Descriptor(
  name='DelAccountReq',
  full_name='tradegw.api.DelAccountReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='tradegw.api.DelAccountReq.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=418,
)


_GETACCOUNTSTATUSESREQ = _descriptor.Descriptor(
  name='GetAccountStatusesReq',
  full_name='tradegw.api.GetAccountStatusesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='tradegw.api.GetAccountStatusesReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='tradegw.api.GetAccountStatusesReq.account_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=498,
)


_SETACCOUNTCUMINOUTREQ = _descriptor.Descriptor(
  name='SetAccountCumInoutReq',
  full_name='tradegw.api.SetAccountCumInoutReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='tradegw.api.SetAccountCumInoutReq.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cum_inout', full_name='tradegw.api.SetAccountCumInoutReq.cum_inout', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=562,
)


_GETACCOUNTREQ = _descriptor.Descriptor(
  name='GetAccountReq',
  full_name='tradegw.api.GetAccountReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='tradegw.api.GetAccountReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='tradegw.api.GetAccountReq.exchange', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='tradegw.api.GetAccountReq.api_key', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_secret', full_name='tradegw.api.GetAccountReq.api_secret', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=668,
)


_GETSYSMESSAGELISTREQ = _descriptor.Descriptor(
  name='GetSysMessageListReq',
  full_name='tradegw.api.GetSysMessageListReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='tradegw.api.GetSysMessageListReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='m_level', full_name='tradegw.api.GetSysMessageListReq.m_level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='m_type', full_name='tradegw.api.GetSysMessageListReq.m_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='tradegw.api.GetSysMessageListReq.start_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='tradegw.api.GetSysMessageListReq.end_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=671,
  serialized_end=843,
)


_GETTRADEMESSAGELISTREQ = _descriptor.Descriptor(
  name='GetTradeMessageListReq',
  full_name='tradegw.api.GetTradeMessageListReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='tradegw.api.GetTradeMessageListReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='tradegw.api.GetTradeMessageListReq.exchange', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='tradegw.api.GetTradeMessageListReq.strategy_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='tradegw.api.GetTradeMessageListReq.start_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='tradegw.api.GetTradeMessageListReq.end_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=846,
  serialized_end=981,
)


_GETEXECRPTMESSAGELISTREQ = _descriptor.Descriptor(
  name='GetExecrptMessageListReq',
  full_name='tradegw.api.GetExecrptMessageListReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='tradegw.api.GetExecrptMessageListReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='tradegw.api.GetExecrptMessageListReq.exchange', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='tradegw.api.GetExecrptMessageListReq.strategy_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='tradegw.api.GetExecrptMessageListReq.start_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='tradegw.api.GetExecrptMessageListReq.end_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=984,
  serialized_end=1121,
)

_GETACCOUNTCONNECTIONSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETACCOUNTSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETACCOUNTSTATUSESREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETACCOUNTREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETSYSMESSAGELISTREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETSYSMESSAGELISTREQ.fields_by_name['m_level'].enum_type = core_dot_api_dot_account__pb2._SYSMSGLEVEL
_GETSYSMESSAGELISTREQ.fields_by_name['m_type'].enum_type = core_dot_api_dot_account__pb2._SYSMSGTYPE
_GETTRADEMESSAGELISTREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETEXECRPTMESSAGELISTREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
DESCRIPTOR.message_types_by_name['GetAccountConnectionsReq'] = _GETACCOUNTCONNECTIONSREQ
DESCRIPTOR.message_types_by_name['DelAccountConnectionsReq'] = _DELACCOUNTCONNECTIONSREQ
DESCRIPTOR.message_types_by_name['GetAccountsReq'] = _GETACCOUNTSREQ
DESCRIPTOR.message_types_by_name['DelAccountReq'] = _DELACCOUNTREQ
DESCRIPTOR.message_types_by_name['GetAccountStatusesReq'] = _GETACCOUNTSTATUSESREQ
DESCRIPTOR.message_types_by_name['SetAccountCumInoutReq'] = _SETACCOUNTCUMINOUTREQ
DESCRIPTOR.message_types_by_name['GetAccountReq'] = _GETACCOUNTREQ
DESCRIPTOR.message_types_by_name['GetSysMessageListReq'] = _GETSYSMESSAGELISTREQ
DESCRIPTOR.message_types_by_name['GetTradeMessageListReq'] = _GETTRADEMESSAGELISTREQ
DESCRIPTOR.message_types_by_name['GetExecrptMessageListReq'] = _GETEXECRPTMESSAGELISTREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAccountConnectionsReq = _reflection.GeneratedProtocolMessageType('GetAccountConnectionsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTCONNECTIONSREQ,
  __module__ = 'tradegw.api.tradegw.service_pb2'
  # @@protoc_insertion_point(class_scope:tradegw.api.GetAccountConnectionsReq)
  ))
_sym_db.RegisterMessage(GetAccountConnectionsReq)

DelAccountConnectionsReq = _reflection.GeneratedProtocolMessageType('DelAccountConnectionsReq', (_message.Message,), dict(
  DESCRIPTOR = _DELACCOUNTCONNECTIONSREQ,
  __module__ = 'tradegw.api.tradegw.service_pb2'
  # @@protoc_insertion_point(class_scope:tradegw.api.DelAccountConnectionsReq)
  ))
_sym_db.RegisterMessage(DelAccountConnectionsReq)

GetAccountsReq = _reflection.GeneratedProtocolMessageType('GetAccountsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTSREQ,
  __module__ = 'tradegw.api.tradegw.service_pb2'
  # @@protoc_insertion_point(class_scope:tradegw.api.GetAccountsReq)
  ))
_sym_db.RegisterMessage(GetAccountsReq)

DelAccountReq = _reflection.GeneratedProtocolMessageType('DelAccountReq', (_message.Message,), dict(
  DESCRIPTOR = _DELACCOUNTREQ,
  __module__ = 'tradegw.api.tradegw.service_pb2'
  # @@protoc_insertion_point(class_scope:tradegw.api.DelAccountReq)
  ))
_sym_db.RegisterMessage(DelAccountReq)

GetAccountStatusesReq = _reflection.GeneratedProtocolMessageType('GetAccountStatusesReq', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTSTATUSESREQ,
  __module__ = 'tradegw.api.tradegw.service_pb2'
  # @@protoc_insertion_point(class_scope:tradegw.api.GetAccountStatusesReq)
  ))
_sym_db.RegisterMessage(GetAccountStatusesReq)

SetAccountCumInoutReq = _reflection.GeneratedProtocolMessageType('SetAccountCumInoutReq', (_message.Message,), dict(
  DESCRIPTOR = _SETACCOUNTCUMINOUTREQ,
  __module__ = 'tradegw.api.tradegw.service_pb2'
  # @@protoc_insertion_point(class_scope:tradegw.api.SetAccountCumInoutReq)
  ))
_sym_db.RegisterMessage(SetAccountCumInoutReq)

GetAccountReq = _reflection.GeneratedProtocolMessageType('GetAccountReq', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTREQ,
  __module__ = 'tradegw.api.tradegw.service_pb2'
  # @@protoc_insertion_point(class_scope:tradegw.api.GetAccountReq)
  ))
_sym_db.RegisterMessage(GetAccountReq)

GetSysMessageListReq = _reflection.GeneratedProtocolMessageType('GetSysMessageListReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSYSMESSAGELISTREQ,
  __module__ = 'tradegw.api.tradegw.service_pb2'
  # @@protoc_insertion_point(class_scope:tradegw.api.GetSysMessageListReq)
  ))
_sym_db.RegisterMessage(GetSysMessageListReq)

GetTradeMessageListReq = _reflection.GeneratedProtocolMessageType('GetTradeMessageListReq', (_message.Message,), dict(
  DESCRIPTOR = _GETTRADEMESSAGELISTREQ,
  __module__ = 'tradegw.api.tradegw.service_pb2'
  # @@protoc_insertion_point(class_scope:tradegw.api.GetTradeMessageListReq)
  ))
_sym_db.RegisterMessage(GetTradeMessageListReq)

GetExecrptMessageListReq = _reflection.GeneratedProtocolMessageType('GetExecrptMessageListReq', (_message.Message,), dict(
  DESCRIPTOR = _GETEXECRPTMESSAGELISTREQ,
  __module__ = 'tradegw.api.tradegw.service_pb2'
  # @@protoc_insertion_point(class_scope:tradegw.api.GetExecrptMessageListReq)
  ))
_sym_db.RegisterMessage(GetExecrptMessageListReq)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z.nextfin.com/nfplatform/tradegw/api;tradegw_api'))

_TRADEGWSERVICE = _descriptor.ServiceDescriptor(
  name='TradegwService',
  full_name='tradegw.api.TradegwService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=1124,
  serialized_end=2002,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddAccountConnection',
    full_name='tradegw.api.TradegwService.AddAccountConnection',
    index=0,
    containing_service=None,
    input_type=core_dot_api_dot_account__pb2._ACCOUNTCONNECTION,
    output_type=core_dot_api_dot_account__pb2._ACCOUNTCONNECTION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\034\"\027/v3/account-connections:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountConnections',
    full_name='tradegw.api.TradegwService.GetAccountConnections',
    index=1,
    containing_service=None,
    input_type=_GETACCOUNTCONNECTIONSREQ,
    output_type=core_dot_api_dot_account__pb2._ACCOUNTCONNECTIONS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\031\022\027/v3/account-connections')),
  ),
  _descriptor.MethodDescriptor(
    name='DelAccountConnections',
    full_name='tradegw.api.TradegwService.DelAccountConnections',
    index=2,
    containing_service=None,
    input_type=_DELACCOUNTCONNECTIONSREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002#\"\036/v3/account-connections/delete:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetOrderSummary',
    full_name='tradegw.api.TradegwService.GetOrderSummary',
    index=3,
    containing_service=None,
    input_type=_DELACCOUNTCONNECTIONSREQ,
    output_type=core_dot_api_dot_account__pb2._ORDERSUMMARYNUM,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002%\022#/v3/account-trade/get-order-summary')),
  ),
  _descriptor.MethodDescriptor(
    name='GetTradeMessageList',
    full_name='tradegw.api.TradegwService.GetTradeMessageList',
    index=4,
    containing_service=None,
    input_type=_GETTRADEMESSAGELISTREQ,
    output_type=core_dot_api_dot_account__pb2._TRADEMESSAGELIST,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\026\"\021/v3/trademsg/list:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetExecrptMessageList',
    full_name='tradegw.api.TradegwService.GetExecrptMessageList',
    index=5,
    containing_service=None,
    input_type=_GETEXECRPTMESSAGELISTREQ,
    output_type=core_dot_api_dot_account__pb2._EXECRPTMESSAGELIST,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\030\"\023/v3/execrptmsg/list:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetSysMessageList',
    full_name='tradegw.api.TradegwService.GetSysMessageList',
    index=6,
    containing_service=None,
    input_type=_GETSYSMESSAGELISTREQ,
    output_type=core_dot_api_dot_account__pb2._SYSMESSAGELIST,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\024\"\017/v3/sysmsg/list:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_TRADEGWSERVICE)

DESCRIPTOR.services_by_name['TradegwService'] = _TRADEGWSERVICE

# @@protoc_insertion_point(module_scope)
