# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strategy/strategy_params/strategy.params.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='strategy/strategy_params/strategy.params.proto',
  package='strategy.params',
  syntax='proto3',
  serialized_pb=_b('\n.strategy/strategy_params/strategy.params.proto\x12\x0fstrategy.params\"\xcc\x04\n\x14StrategyDuidaoParams\x12\x13\n\x0blogFilePath\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\x12\r\n\x05\x66ront\x18\x05 \x01(\t\x12\x0c\n\x04rear\x18\x06 \x01(\t\x12\x0e\n\x06symbol\x18\x07 \x01(\t\x12\x12\n\nsymbolMark\x18\x08 \x01(\t\x12\x18\n\x10\x63\x61lmDownTimeStep\x18\t \x01(\x03\x12\x18\n\x10\x63\x61lmDownTimeStop\x18\n \x01(\x03\x12\x0e\n\x06volSum\x18\x0b \x01(\x01\x12\x0f\n\x07timeSum\x18\x0c \x01(\x03\x12\x10\n\x08stepTime\x18\r \x01(\x03\x12\x0e\n\x06\x62idNum\x18\x0e \x01(\x03\x12\x0e\n\x06\x61skNum\x18\x0f \x01(\x03\x12\x14\n\x0csingleVolMin\x18\x10 \x01(\x01\x12\x14\n\x0csingleVolMax\x18\x11 \x01(\x01\x12\x11\n\tinitPrice\x18\x12 \x01(\x01\x12\x0f\n\x07testVol\x18\x13 \x01(\x01\x12\x14\n\x0cinvVolumnNum\x18\x14 \x01(\x01\x12\x1f\n\x17singleDoneBuyRateWaring\x18\x15 \x01(\x01\x12 \n\x18SingleDoneSellRateWaring\x18\x16 \x01(\x01\x12\x1c\n\x14\x43\x61lDoneBuyRateWaring\x18\x17 \x01(\x01\x12\x1d\n\x15\x43\x61lDoneSellRateWaring\x18\x18 \x01(\x01\x12\x15\n\rsymbolDecimal\x18\x19 \x01(\x01\x12\x18\n\x10symbolDecimalNum\x18\x1a \x01(\x03\x12\x17\n\x0f\x61\x62sPriceCelling\x18\x1b \x01(\x01\x12\x15\n\rabsPriceFloor\x18\x1c \x01(\x01\"\xe8\x02\n\x13StrategyBudanParams\x12\x13\n\x0blogFilePath\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\x12\r\n\x05\x66ront\x18\x05 \x01(\t\x12\x0c\n\x04rear\x18\x06 \x01(\t\x12\x0e\n\x06symbol\x18\x07 \x01(\t\x12\x11\n\tbuyOrSell\x18\x08 \x01(\x03\x12\x14\n\x0cshiftOrPrice\x18\t \x01(\x03\x12\x0e\n\x06\x62order\x18\n \x01(\x01\x12\x0f\n\x07lineNum\x18\x0b \x01(\x03\x12\x0e\n\x06volSum\x18\x0c \x01(\x01\x12\x0e\n\x06volMin\x18\r \x01(\x01\x12\x11\n\tinitPrice\x18\x0e \x01(\x01\x12\r\n\x05state\x18\x0f \x01(\x03\x12\x0e\n\x06tdHigh\x18\x10 \x01(\x03\x12\r\n\x05tdLow\x18\x11 \x01(\x03\x12\x12\n\nwaringRate\x18\x12 \x01(\x01\x12\x11\n\tstopOrNot\x18\x13 \x01(\x03\x12\x11\n\tunitPrice\x18\x14 \x01(\x01\x12\x18\n\x10symbolDecimalNum\x18\x15 \x01(\x03\"\xfa\x02\n\x13StrategyLapanParams\x12\x13\n\x0blogFilePath\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\x12\r\n\x05\x66ront\x18\x05 \x01(\t\x12\x0c\n\x04rear\x18\x06 \x01(\t\x12\x0e\n\x06symbol\x18\x07 \x01(\t\x12\x0c\n\x04mode\x18\x08 \x01(\x03\x12\x15\n\rmeanTimeIntvl\x18\t \x01(\x03\x12\x16\n\x0etotalTimeLimit\x18\n \x01(\x03\x12\x14\n\x0cmeanOrderVol\x18\x0b \x01(\x01\x12\x17\n\x0fpriceChangeRate\x18\x0c \x01(\x01\x12\x16\n\x0emeanPriceLimit\x18\r \x01(\x01\x12\x15\n\rtotalVolLimit\x18\x0e \x01(\x01\x12\x13\n\x0bpriceTarget\x18\x0f \x01(\x01\x12\x15\n\rprecautionVol\x18\x10 \x01(\x01\x12\x17\n\x0fprecautionPrice\x18\x11 \x01(\x01\x12\x15\n\rsymbolDecimal\x18\x12 \x01(\x01\x12\x18\n\x10symbolDecimalNum\x18\x13 \x01(\x03\x62\x06proto3')
)




_STRATEGYDUIDAOPARAMS = _descriptor.Descriptor(
  name='StrategyDuidaoParams',
  full_name='strategy.params.StrategyDuidaoParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logFilePath', full_name='strategy.params.StrategyDuidaoParams.logFilePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='strategy.params.StrategyDuidaoParams.exchange', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='strategy.params.StrategyDuidaoParams.front', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='strategy.params.StrategyDuidaoParams.rear', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='strategy.params.StrategyDuidaoParams.symbol', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbolMark', full_name='strategy.params.StrategyDuidaoParams.symbolMark', index=5,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calmDownTimeStep', full_name='strategy.params.StrategyDuidaoParams.calmDownTimeStep', index=6,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calmDownTimeStop', full_name='strategy.params.StrategyDuidaoParams.calmDownTimeStop', index=7,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volSum', full_name='strategy.params.StrategyDuidaoParams.volSum', index=8,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeSum', full_name='strategy.params.StrategyDuidaoParams.timeSum', index=9,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stepTime', full_name='strategy.params.StrategyDuidaoParams.stepTime', index=10,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bidNum', full_name='strategy.params.StrategyDuidaoParams.bidNum', index=11,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='askNum', full_name='strategy.params.StrategyDuidaoParams.askNum', index=12,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='singleVolMin', full_name='strategy.params.StrategyDuidaoParams.singleVolMin', index=13,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='singleVolMax', full_name='strategy.params.StrategyDuidaoParams.singleVolMax', index=14,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initPrice', full_name='strategy.params.StrategyDuidaoParams.initPrice', index=15,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='testVol', full_name='strategy.params.StrategyDuidaoParams.testVol', index=16,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invVolumnNum', full_name='strategy.params.StrategyDuidaoParams.invVolumnNum', index=17,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='singleDoneBuyRateWaring', full_name='strategy.params.StrategyDuidaoParams.singleDoneBuyRateWaring', index=18,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='SingleDoneSellRateWaring', full_name='strategy.params.StrategyDuidaoParams.SingleDoneSellRateWaring', index=19,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='CalDoneBuyRateWaring', full_name='strategy.params.StrategyDuidaoParams.CalDoneBuyRateWaring', index=20,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='CalDoneSellRateWaring', full_name='strategy.params.StrategyDuidaoParams.CalDoneSellRateWaring', index=21,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbolDecimal', full_name='strategy.params.StrategyDuidaoParams.symbolDecimal', index=22,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbolDecimalNum', full_name='strategy.params.StrategyDuidaoParams.symbolDecimalNum', index=23,
      number=26, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='absPriceCelling', full_name='strategy.params.StrategyDuidaoParams.absPriceCelling', index=24,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='absPriceFloor', full_name='strategy.params.StrategyDuidaoParams.absPriceFloor', index=25,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=656,
)


_STRATEGYBUDANPARAMS = _descriptor.Descriptor(
  name='StrategyBudanParams',
  full_name='strategy.params.StrategyBudanParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logFilePath', full_name='strategy.params.StrategyBudanParams.logFilePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='strategy.params.StrategyBudanParams.exchange', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='strategy.params.StrategyBudanParams.front', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='strategy.params.StrategyBudanParams.rear', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='strategy.params.StrategyBudanParams.symbol', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buyOrSell', full_name='strategy.params.StrategyBudanParams.buyOrSell', index=5,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shiftOrPrice', full_name='strategy.params.StrategyBudanParams.shiftOrPrice', index=6,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='border', full_name='strategy.params.StrategyBudanParams.border', index=7,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lineNum', full_name='strategy.params.StrategyBudanParams.lineNum', index=8,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volSum', full_name='strategy.params.StrategyBudanParams.volSum', index=9,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volMin', full_name='strategy.params.StrategyBudanParams.volMin', index=10,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initPrice', full_name='strategy.params.StrategyBudanParams.initPrice', index=11,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='strategy.params.StrategyBudanParams.state', index=12,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tdHigh', full_name='strategy.params.StrategyBudanParams.tdHigh', index=13,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tdLow', full_name='strategy.params.StrategyBudanParams.tdLow', index=14,
      number=17, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='waringRate', full_name='strategy.params.StrategyBudanParams.waringRate', index=15,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stopOrNot', full_name='strategy.params.StrategyBudanParams.stopOrNot', index=16,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unitPrice', full_name='strategy.params.StrategyBudanParams.unitPrice', index=17,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbolDecimalNum', full_name='strategy.params.StrategyBudanParams.symbolDecimalNum', index=18,
      number=21, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=659,
  serialized_end=1019,
)


_STRATEGYLAPANPARAMS = _descriptor.Descriptor(
  name='StrategyLapanParams',
  full_name='strategy.params.StrategyLapanParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logFilePath', full_name='strategy.params.StrategyLapanParams.logFilePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='strategy.params.StrategyLapanParams.exchange', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='strategy.params.StrategyLapanParams.front', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='strategy.params.StrategyLapanParams.rear', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='strategy.params.StrategyLapanParams.symbol', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mode', full_name='strategy.params.StrategyLapanParams.mode', index=5,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='meanTimeIntvl', full_name='strategy.params.StrategyLapanParams.meanTimeIntvl', index=6,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='totalTimeLimit', full_name='strategy.params.StrategyLapanParams.totalTimeLimit', index=7,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='meanOrderVol', full_name='strategy.params.StrategyLapanParams.meanOrderVol', index=8,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='priceChangeRate', full_name='strategy.params.StrategyLapanParams.priceChangeRate', index=9,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='meanPriceLimit', full_name='strategy.params.StrategyLapanParams.meanPriceLimit', index=10,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='totalVolLimit', full_name='strategy.params.StrategyLapanParams.totalVolLimit', index=11,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='priceTarget', full_name='strategy.params.StrategyLapanParams.priceTarget', index=12,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='precautionVol', full_name='strategy.params.StrategyLapanParams.precautionVol', index=13,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='precautionPrice', full_name='strategy.params.StrategyLapanParams.precautionPrice', index=14,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbolDecimal', full_name='strategy.params.StrategyLapanParams.symbolDecimal', index=15,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbolDecimalNum', full_name='strategy.params.StrategyLapanParams.symbolDecimalNum', index=16,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1022,
  serialized_end=1400,
)

DESCRIPTOR.message_types_by_name['StrategyDuidaoParams'] = _STRATEGYDUIDAOPARAMS
DESCRIPTOR.message_types_by_name['StrategyBudanParams'] = _STRATEGYBUDANPARAMS
DESCRIPTOR.message_types_by_name['StrategyLapanParams'] = _STRATEGYLAPANPARAMS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StrategyDuidaoParams = _reflection.GeneratedProtocolMessageType('StrategyDuidaoParams', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYDUIDAOPARAMS,
  __module__ = 'strategy.strategy_params.strategy.params_pb2'
  # @@protoc_insertion_point(class_scope:strategy.params.StrategyDuidaoParams)
  ))
_sym_db.RegisterMessage(StrategyDuidaoParams)

StrategyBudanParams = _reflection.GeneratedProtocolMessageType('StrategyBudanParams', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYBUDANPARAMS,
  __module__ = 'strategy.strategy_params.strategy.params_pb2'
  # @@protoc_insertion_point(class_scope:strategy.params.StrategyBudanParams)
  ))
_sym_db.RegisterMessage(StrategyBudanParams)

StrategyLapanParams = _reflection.GeneratedProtocolMessageType('StrategyLapanParams', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYLAPANPARAMS,
  __module__ = 'strategy.strategy_params.strategy.params_pb2'
  # @@protoc_insertion_point(class_scope:strategy.params.StrategyLapanParams)
  ))
_sym_db.RegisterMessage(StrategyLapanParams)


# @@protoc_insertion_point(module_scope)
