# coding=utf-8
from __future__ import unicode_literals, print_function, absolute_import

__title__ = 'nft-sdk'
__description__ = 'NextFintech sdk'
__url__ = 'http://NextFintech.com/'
__version__ = '2.1.0.1'
__author__ = 'NextFintech'
__author_email__ = 'support@NextFintech.com'
__license__ = 'Apache 2.0'


