# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/api/report.service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from nf.pb.core.api import account_pb2 as core_dot_api_dot_account__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core/api/report.service.proto',
  package='core.api',
  syntax='proto3',
  serialized_pb=_b('\n\x1d\x63ore/api/report.service.proto\x12\x08\x63ore.api\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x16\x63ore/api/account.proto\"\x92\x01\n\x0e\x41\x64\x64ReportEvent\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nuser_token\x18\x02 \x01(\t\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x12\n\napi_secret\x18\x05 \x01(\t\x12\x12\n\naccount_id\x18\x06 \x01(\t\x12\x10\n\x08password\x18\x07 \x01(\t\"^\n\x11RemoveReportEvent\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nuser_token\x18\x02 \x01(\t\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\x12\n\naccount_id\x18\x04 \x01(\t\".\n\x0fReportEventResp\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xb5\x02\n\rReportService\x12\x61\n\x0e\x61\x64\x64TradeReport\x12\x18.core.api.AddReportEvent\x1a\x19.core.api.ReportEventResp\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v3/tradereport:\x01*\x12n\n\x11removeTradeReport\x12\x1b.core.api.RemoveReportEvent\x1a\x19.core.api.ReportEventResp\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v3/tradereport/delete:\x01*\x12Q\n\nsendReport\x12\x11.core.api.ExecRpt\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v3/tradereportsB`\n$com.nextfintech.tradingcenter.reportB\x0cReportServerP\x01Z(nextfin.com/nfplatform/core/api;core_apib\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,core_dot_api_dot_account__pb2.DESCRIPTOR,])




_ADDREPORTEVENT = _descriptor.Descriptor(
  name='AddReportEvent',
  full_name='core.api.AddReportEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='core.api.AddReportEvent.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_token', full_name='core.api.AddReportEvent.user_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='core.api.AddReportEvent.exchange', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='core.api.AddReportEvent.api_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_secret', full_name='core.api.AddReportEvent.api_secret', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='core.api.AddReportEvent.account_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='core.api.AddReportEvent.password', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=273,
)


_REMOVEREPORTEVENT = _descriptor.Descriptor(
  name='RemoveReportEvent',
  full_name='core.api.RemoveReportEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='core.api.RemoveReportEvent.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_token', full_name='core.api.RemoveReportEvent.user_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='core.api.RemoveReportEvent.exchange', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='core.api.RemoveReportEvent.account_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=369,
)


_REPORTEVENTRESP = _descriptor.Descriptor(
  name='ReportEventResp',
  full_name='core.api.ReportEventResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='core.api.ReportEventResp.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg', full_name='core.api.ReportEventResp.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=417,
)

DESCRIPTOR.message_types_by_name['AddReportEvent'] = _ADDREPORTEVENT
DESCRIPTOR.message_types_by_name['RemoveReportEvent'] = _REMOVEREPORTEVENT
DESCRIPTOR.message_types_by_name['ReportEventResp'] = _REPORTEVENTRESP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AddReportEvent = _reflection.GeneratedProtocolMessageType('AddReportEvent', (_message.Message,), dict(
  DESCRIPTOR = _ADDREPORTEVENT,
  __module__ = 'core.api.report.service_pb2'
  # @@protoc_insertion_point(class_scope:core.api.AddReportEvent)
  ))
_sym_db.RegisterMessage(AddReportEvent)

RemoveReportEvent = _reflection.GeneratedProtocolMessageType('RemoveReportEvent', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEREPORTEVENT,
  __module__ = 'core.api.report.service_pb2'
  # @@protoc_insertion_point(class_scope:core.api.RemoveReportEvent)
  ))
_sym_db.RegisterMessage(RemoveReportEvent)

ReportEventResp = _reflection.GeneratedProtocolMessageType('ReportEventResp', (_message.Message,), dict(
  DESCRIPTOR = _REPORTEVENTRESP,
  __module__ = 'core.api.report.service_pb2'
  # @@protoc_insertion_point(class_scope:core.api.ReportEventResp)
  ))
_sym_db.RegisterMessage(ReportEventResp)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.nextfintech.tradingcenter.reportB\014ReportServerP\001Z(nextfin.com/nfplatform/core/api;core_api'))

_REPORTSERVICE = _descriptor.ServiceDescriptor(
  name='ReportService',
  full_name='core.api.ReportService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=420,
  serialized_end=729,
  methods=[
  _descriptor.MethodDescriptor(
    name='addTradeReport',
    full_name='core.api.ReportService.addTradeReport',
    index=0,
    containing_service=None,
    input_type=_ADDREPORTEVENT,
    output_type=_REPORTEVENTRESP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\024\"\017/v3/tradereport:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='removeTradeReport',
    full_name='core.api.ReportService.removeTradeReport',
    index=1,
    containing_service=None,
    input_type=_REMOVEREPORTEVENT,
    output_type=_REPORTEVENTRESP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\033\"\026/v3/tradereport/delete:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='sendReport',
    full_name='core.api.ReportService.sendReport',
    index=2,
    containing_service=None,
    input_type=core_dot_api_dot_account__pb2._EXECRPT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\022\022\020/v3/tradereports')),
  ),
])
_sym_db.RegisterServiceDescriptor(_REPORTSERVICE)

DESCRIPTOR.services_by_name['ReportService'] = _REPORTSERVICE

# @@protoc_insertion_point(module_scope)
